@@ -4,6 +4,7 @@ import copy
 from ctypes import CDLL, POINTER, c_double, c_char_p, pointer
 from ctypes.util import find_library
 import fnmatch
+from urlparse import urlparse
 from collections import MutableMapping
 from datetime import datetime, timedelta
 import redis
@@ -11,7 +12,7 @@ from redis.exceptions import ResponseError
 import redis.client
 
 
-__version__ = '0.4.0'
+__version__ = '0.4.1'
 DATABASES = {}
 
 _libc = CDLL(find_library('c'))
@@ -66,6 +67,16 @@ class _StrKeyDict(MutableMapping):
 
 
 class FakeStrictRedis(object):
+    @classmethod
+    def from_url(cls, url, db=None, **kwargs):
+        url = urlparse(url)
+        if db is None:
+            try:
+                db = int(url.path.replace('/', ''))
+            except (AttributeError, ValueError):
+                db = 0
+        return cls(db=db)
+
     def __init__(self, db=0, **kwargs):
         if db not in DATABASES:
             DATABASES[db] = _StrKeyDict()
